extensions [r]

globals[
  ;; schedule
  week year years_to_simulate 
  ;; predation submodule
  D predat P_min
  ;; survival submodule
  R s_wean s_fem
  ;; dispersal submodule
  A_em b_sex b_stage b_dens b1 b2 b3 b_em
  ;; reproduction submodule
  Numlit Min_numlit Max_numlit a_rep b_rep Max_repuni Max_wean
  ;; output + plotting
  totind totad totsubad weeks obs_springsize springtotobs obs_autumnsize autumntotobs Sdate Adate predators 
  ;; calculate_cycle 
  period corr_period period_half corr_period_half Spperiod Spcorr_period Spperiod_half Spcorr_period_half ampl sampl
]
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;     explanation of globals       ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
;; predation submodule
;; D - predation half-saturation constant
;; predat - a global containing predator population size
;; Q - predator-prey ratio constant (is on the interface now)
;; Smax - predator intrinsic rate of increase (is on the interface now)
;; c - maximum consumption per predator (is on the interface now)
;; dlow - predator mortality rate when prey is scarce (is on the interface now)
;; Ncrit - critical prey pop. size (is on the interface now)  - ! here reclaculated to the size of the sys-m: 0.5ha
;; P_min - minimum predator population size

;; survival submodule
;; R - winter maximum population growth rate
;; s_wean - survival probability of weanlings in case of male turnover
;; s_fem - female survival probability in case of male turnover
;; Kwin - winter carrying capacity (is on the interface now)
;; sumsurv - summer survival probability (is on interface now)

;; dispersal submodule
;; A_em - intercept in the emigration equation
;; b_sex - effect of sex on emigration
;; b_stage - effect of stage on emigration
;; b_dens - effect of density on emigration
;; b1 - Coefficient for sex*stage interaction in the emigration equation 
;; b2 - Coefficient for density*stage interaction in the emigration equation
;; b3 - Coefficient for density*sex interaction in the emigration equation
;; b_em - maximum in the uniform distribution used in in the emigration equation
;; dispsurv - dispersal survival (is on interface)

;; reproduction submodule
;; Numlit - parameter for the Poisson distribution for the number of litters to be produced
;; Min_numlit - minimum number of litters
;; Max_numlit - maximum number of litters
;; a_rep - intercept in the reproduction equation
;; b_rep - effect of sociality in the reproduciton equation
;; Max_repuni - the maximum in the uniform distribution used in the reproduction equation
;; Max_wean - the maximum number of weanlings
;; maxreproductive - the maximum number of reproducing females in the patch

;; processing / output
;; totind - a vector containing total number of voles each week in the system
;; totad - a vector containing total number of adult voles each week in the system
;; totsubad - a vector containing total number of subadult voles each week in the system
;; weeks - a vector storing the week
;; obs_springsize - total number of voles observed in the system in spring (week = 16)
;; springtotobs - a vector containing the total number of voles observed in the system each spring (week = 16)
;; obs_autumnsize total number of voles observed in the system in autumn (week = 39) 
;; autumntotobs - a vector containing the total number of voles observed in the system each autumn (week = 39)
;; Sdate - a vector containing the week in spring when observations are done 
;; Adate - a vector containing the week in autumn when observations are done 
;; predators - a vector containing the total number of predators observed in the system in autumn

;; period - the period of the cycle as identified from the autocorrelation at maximum positive lag calculated on autumn time series
;; corr_period - correlation at the maximum period calculated on autumn time series
;; period_half - the lag at which min negative autocorrelation is observed on autumn time series
;; corr_period_half - the correlation for the period_half
;; Spperiod - the period of the cycle as identified from the autocorrelation at maximum positive lag calculated on spring time series
;; Spcorr_period - correlation at the maximum period calculated on spring time series
;; Spperiod_half - the lag at which max negative autocorrelation is observed on spring time series
;; Spcorr_period_half - the correlation for the Spperiod_half
;; ampl - amplitude for the autumn time series
;; sampl - amplitude for the spring time series

breed[voles vole]
voles-own[sex age stat family reprod mature numlitters f_reprod weeks_since_rep mydom num_wean]
; sex, Female = 0, Male = 1
; age - age in weeks
; stat - breed (either adults = 1, or subadults = 0)
; family - identity of the family an individual belongs to
; reprod - reproductive individual
; mature - mature individuals (both reproducing and not)
; numlitters is the number of litters to be (yet) reproduced
; f_reprod indicates whether a female reproduced this reproduction period already
; weeks_since_rep - weeks since last reproduction
; mydom - ID of mydom male (or female)
; num_wean - the numer of weanlings to be born

patches-own[hab dens]


to setup
  clear-all
  r:clear
  
  set week 25
  set year 1
  set years_to_simulate 36
  set totind []
  set totad []
  set totsubad []
  set weeks []
  set obs_springsize 0
  set springtotobs[]
  set obs_autumnsize 0
  set autumntotobs[]
  set Sdate []
  set Adate []
  
  ;; initializing par-rs
  
  ;; 1. predation
  set D 3      
  set P_min 0.0025

  ;; 2. survival
  set s_wean 0.38
  set s_fem 0.87
  set R 0.4
  
  ;; 3. Dispersal
  set A_em -1.247
  set b_sex -0.5542
  set b_stage 0.2212
  set b_dens -0.8463  
  set b1 -1.5017  
  set b2 0.4933
  set b3 0.2873 
  set b_em 0.814
  
  ;; 4. Reproduction
  set Numlit 3.12
  set Max_numlit 5
  set Min_numlit 1
  set a_rep 0.775
  set b_rep 0.0113
  set Max_repuni 0.45
  set Max_wean 6
  
  ;; parameters for outputting
  set period 0
  set corr_period 0
  set period_half 0
  set corr_period_half 0
  set Spperiod 0
  set Spcorr_period 0
  set Spperiod_half 0
  set Spcorr_period_half 0
  set predators []
  set ampl 0
  
  spatial_visualize
  set-individuals
      
  reset-ticks
end


; visualizing 6 patches-territories
to spatial_visualize
  
  ask patches 
  [
    if (pycor <= 3 and pycor > 1) AND (pxcor >= -5 and pxcor < -3)
    [set hab 1]
    if (pycor <= 3 and pycor > 1) AND (pxcor >= -1 and pxcor < 1)
    [set hab 2]
    if (pycor <= 3 and pycor > 1) AND (pxcor >= 3 and pxcor < 5)
    [set hab 3]
    if (pycor < -1 and pycor >= -3) AND (pxcor >= -5 and pxcor < -3)
    [set hab 4]
    if (pycor < -1 and pycor >= -3) AND (pxcor >= -1 and pxcor < 1)
    [set hab 5]
    if (pycor < -1 and pycor >= -3) AND (pxcor >= 3 and pxcor < 5)
    [set hab 6]
  ]
  ask patches with [hab > 0] [set pcolor white]  
end

to set-individuals
  create-voles 4[  ;; creating adults
    set color red
    set sex 0
    set age 39 + random (52 - 39)
    set reprod 1
    set mature 1
    set stat 1
    set numlitters random-poisson Numlit
    if numlitters > 5 [set numlitters Max_numlit]
    if numlitters <= 0 [set numlitters Min_numlit]
    ;    show word "my number litters" numlitters
    set f_reprod 1
    set mydom -1
    set weeks_since_rep 4
    set family who
    ;    show word "family is" family
    let myhab (random 5) + 1
    ;    show word "myhab" myhab
    let mypatches patches with [hab = myhab]
    while [any? voles-on mypatches]
    [
      ;      show "entered the loop"
      set myhab (random 5) + 1
      ;      show word "myhab" myhab
      set mypatches patches with [hab = myhab]
    ]
    move-to one-of mypatches 
  ]
  
  let occupied ([hab] of patches with [any? voles-here])
  ;  show word "occupied" occupied
  
  foreach occupied [
    let num random-poisson 4.3676 
    ;    show word "num subadults" num
    while [num > 10 OR num = 0]
    [
      set num random-poisson 4.3676
      ;      show word "num subadults" num 
    ]
    create-voles num ;; creating subadults
    [ 
      set age 2
      set stat 0
      set reprod 0
      set mature 0
      set numlitters 0
      set f_reprod 0
      set mydom -1 
      set family [family] of one-of voles-on patches with [hab = ?]
      ;      show word "my family is" family
      
      move-to one-of patches with [hab = ?]
      ifelse random-bernoulli 0.5
      [set sex 0
        set color red]
      [set sex 1
        set color blue]
    ]
  ] 
end


to go
  
  if (week = 52 and year = years_to_simulate) OR (not any? turtles) 
  [
    calculate-cycle
    show "end of simulation"   
    stop
  ]
  
  schedule
  survive
  
  if pred = TRUE[
    if week = 44 and year > 4
    [
      assess-predatorpop
      predate
    ]
  ]
  
  if disp = TRUE
  [
    if (week >= 17 and week <= 43)[
      disperse]
  ]
  
  if (week >= 17 and week <= 43) [
    reproduce]
  
  update-status
  
  tick
  do-plots-stat
  if week = 16
  [do-spring-observed]
  
  ;; mimickig the field autumn observations
  if week = 44
  [do-autumn-observed] 
end


to schedule
  set week week + 1
  if week = 53 [
    set year year + 1
    set week 1
  ]
end


to survive
  
  ;; first asking all reproductive females whose male dies to set higher mortality
  
  let reproductive_fem voles with [stat = 1 and sex = 0 and reprod = 1]
  ;  show word "list of reproductive" list_reproductive

  
  ask reproductive_fem
  [
    ;    show word "reproductive now" ?
    let dom_males voles with [stat = 1 and sex = 1 and reprod = 1]
    ;    show word "dominant_males" dom_males

        if mydom != -1
        [
          let myhab hab
          ;          show word "my hab is" myhab
          ;          show word "mydom is" mydom ;; to check if this female already had a dominant male assigned
          ;          show word "any dominant males with who = mydom" adult mydom
          ;          show word "any dominant males with hab = myhab" any? dom_males with [hab = myhab] 
          ifelse not any? dom_males with [hab = myhab] 
          [
            ; male infanticide (females are not able to wean if male turnover occurs)
            
            if maleinfantic = TRUE
            [
              if any? voles with [stat = 0 and age < 3 and family = [who] of myself ]
              [
                let surv s_wean
                if random-float 1.0 > surv
                  [
                    ask voles with [stat = 0 and age < 3 and family = [who] of myself ]
                    [
                      ;                show word "I'll die because dommale died" who 
                      die
                    ]
                  ]
              ]
            ]
            
            
            ;;higher female mortality if male turnover
            if FemMort = TRUE
            [
              let surv s_fem
              if random-float 1.0 > surv
                [
                  die]
            ]
            
          ] ;; close loop for not any? dominant males here
          
            ;; in case some dominant males are present
          [
            ;            show word "who of dominant males here" [who] of one-of dom_males with [hab = myhab]
            ifelse [who] of one-of dom_males with [hab = myhab] != mydom
            [
              ; male infanticide (females are not able to wean if male turnover)
              if maleinfantic = TRUE
              [              
                if any? voles with [stat = 0 and age < 3 and family = [who] of myself ]
                [
                  let surv s_wean
                  if random-float 1 > surv
                  [
                    ask voles with [stat = 0 and age < 3 and family = [who] of myself ]
                    [
                      ;                show word "I'll die because dommale died" who 
                      die
                    ]
                  ]
                ]
              ]
              
              
              ;;higher female mortality if male turnover 
              if FemMort = TRUE
              [
                let surv s_fem
                if random-float 1.0 > surv
                [
                  die]
              ]
              
            ]
            [
              ;; survival in case dominant male is there
              let surv sumsurv
              if random-float 1.0 > surv
              [
                die]
            ]
          ] ;; close loop for the case when there are some dominant males
        ]
  ] ;; closing the loop for all reproductive
  
  
    ;; adding the death of all weanlings if a mom is dead
  ask voles with [stat = 0 and age < 3]
  [
    ;    show word "family" family
    ;    show word "any? moms around" any? adults with [sex = 0 and f_reprod = 1 and who = [family] of myself]
    ifelse not any? voles with [stat = 1 and sex = 0 and f_reprod = 1 and who = [family] of myself]
    [
      ;       show word "moms" [who] of adults with [sex = 0 and f_reprod = 1]
      ;      write "I will die"
      die
    ]
    [
      ;; if it is summer
      ifelse week <= 43 and week >= 17
      [
        let surv sumsurv
        if random-float 1.0 > surv
        [die]
      ]
      [
        ;; if it is winter
        let numind count voles with [hab = [hab] of myself]
        ;        show word "hab" hab
        ;        show word "dens" numind
        ;        show word "count of turtles with myhab"count turtles with [hab = [hab] of myself] 
        let surv ( 1 /(1 + (exp(R)- 1)* numind / Kwin))^(1 / 26)
        if random-float 1.0 > surv
        [die]
        
      ] ;; winter close
    ] ;; if my mom is alive close
  ]
  
  ;; applying the survival procedure to all others excluding reproductive females and their weanlingss
  let others_ad voles with [stat = 1 and (sex != 0 OR reprod != 1)]
  let others_sub voles with [stat = 0 and age >= 3]
  ;; summer survival probability
  ifelse week <= 43 and week >= 17
  [
    ask others_ad
    [
      let surv sumsurv
      if random-float 1.0 > surv
      [die]
      
    ]
    
    ask others_sub
    [
      let surv sumsurv
      if random-float 1.0 > surv
      [die]
    ]
  ]
  ;; winter survival probability
  [
    ask others_ad 
      [
        let numind count voles with [hab = [hab] of myself]
        ;        show word "hab" hab
        ;        show word "dens" numind
        ;        show word "count of turtles with myhab"count turtles with [hab = [hab] of myself] 
        let surv ( 1 /(1 + (exp(R)- 1)* numind / Kwin))^(1 / 26)   
        if random-float 1.0 > surv
        [die]
      ]
    
    ask others_sub 
      [
        let numind count voles with [hab = [hab] of myself]
        ;        show word "hab" hab
        ;        show word "dens" numind
        ;        show word "count of turtles with myhab"count turtles with [hab = [hab] of myself] 
        let surv ( 1 /(1 + (exp(R)- 1)* numind / Kwin))^(1 / 26)
        if random-float 1.0 > surv
        [die]
      ]
  ] ;; close winter mortality
  
   ;; removing the females born in previous year because in the field those live rarely to wean in the next year
  if week = 16
  [
    ;    show word "reprods endwinter" adults with [reprod = 1]
    if any? voles with [stat = 1 and reprod = 1]
    [ask voles with [stat = 1 and reprod = 1]
      [die]
    ;    show word "reprods endwinter afterdelete" adults with [reprod = 1]
    ]
  ]
end


to assess-predatorpop
  let numprey count voles
  ;; initiate predator popsize using the popsize of prey and prey/predator ratio
  ifelse year = 5 
  [
    set predat numprey / Q
    ;    show word "prednum" predat
  ]
  ;; if not the first week, update predators popsize as a function of vole popsize
  [
    let predgrowth 0
    ;; checking whether the vole popsize is higher than the critical threshold
    ifelse (numprey) > Ncrit
      [
        set predgrowth Smax * (1 - (Q * predat) / numprey)
        ;        show word "predator growth rate" predgrowth
        ;        show word "exp predator growth rate" exp predgrowth
      ]
      [
        ;; if prey popsize <= Ncrit, apply mortality
        set predgrowth dlow
        ;        show word "predator growth rate" predgrowth
        ;        show word "exp predator growth rate" exp predgrowth
      ]
    set predat predat * exp(predgrowth)
    ;    show word "new predator popsize" predat
    if predat < P_min  [set predat P_min] ;; setting the minimum predator popsize
  ]
end

to predate
  let numprey count voles
  ;    show word "number voles" numprey
  ;    show word "number predators" predat
  ;; predating on the prey
  let predated  c * predat / (numprey + D)
  ;    show word "voles to be predated" predated
  
  let nkil exp(predated)   
  if (numprey) > Ncrit ;; only in case the vole pop is bigger than the critical size
    [
      ifelse nkil < numprey
      [ask n-of nkil voles
        [die] 
      ]
      [ask n-of (numprey - Ncrit) voles
        [die]]
    ]
end




to disperse
  
  ;; 1. Emigration
  ;; assessing the density
  let occupied patches with [any? voles-here] 
  ;  show word "ID of occupied patches" occupied
  let habs [hab] of occupied
  ;  show word "hab of patches" habs
  let terits remove-duplicates habs
  set terits remove 0 terits   
  ;  show word "territories" terits
  
  let disp_potential voles with [age >= 3]
  let abund map [count disp_potential with [hab = ?]] terits
  let density map [? / 225] abund 
  
    (foreach terits density [ask patches with [hab = ?1] [set dens ?2 ]])
  ask voles with [age >= 3]
  [
    ;; redefining the sex
    let S 0
;    show word "S" S
    ifelse sex = 0
    [set S 1]
    [set S 0]
;        show word "S" S
;        show word "my sex" sex
    
    let y_emigr (A_em + b_sex * S + b_stage * stat + b_dens * dens +  b1 *  S * stat + b2 * dens * stat + b3 * dens * S + random-float b_em)
    let prob_emigr ( 1 / (1 + exp (- y_emigr)))
    
    ; 2. Immigration
    if random-bernoulli prob_emigr
    [
      ;apply dispersal mortality to dispersing subadults
      let surv dispsurv
      if random-float 1.0 > surv
        [die]
      
      ;; if survived, then testing the other enclosures
      ; memorize the hab of "home" enclosure 
      let init_hab hab
      let other_hab [hab] of patches with [hab != init_hab]
      ;      show word "other habs" other_hab
      set other_hab remove-duplicates other_hab
      set other_hab remove 0 other_hab
      ;      show word "unique other habs" other_hab
      let moved 0
      while [moved != 1 AND not empty? other_hab]
      [
        let test one-of other_hab
        ;        show word "hab now" test
        ;        show word "any adults of my sex here" any? adults with [sex = [sex] of myself and hab = test]
        ;        show word "sex of adults here" [sex] of adults with [hab = test]
        if not any? voles with [stat = 1 and sex = [sex] of myself and hab = test]
        [move-to one-of patches with [hab = test] 
          set moved 1
          if stat = 1 and mature = 1
          [
            ;            show word "my reprod" reprod
            ;            show word "my mature" mature
            if reprod != 1
            [
              set reprod 1
            ] 
          ]
        ] ;; closing the loop for moved into patch
        set other_hab remove test other_hab
        ;        show word "other_hab now" other_hab
      ] ;; closing while loop
    ] ;closing the loop for emigrants
  ] ;; closing the loop for all potentially dispersing individuals 
end


to reproduce
  ;; 1. Updating the pool of reproductive females (up to maxreprod value)
  let habs [hab] of patches
  let terits remove-duplicates habs
  set terits remove 0 terits
  
  ;  show word "reproductive females" [who] of adults with [sex = 0 and reprod = 1]
  if any? voles with [stat = 1 and sex = 0 and mature = 1 and reprod != 1]
    [
      foreach terits
        [
          ;      show word "hab now" ?
          let potential_reprod voles with [stat = 1 and sex = 0 and hab = ? and mature = 1 and reprod != 1]
          if any? potential_reprod
          [
            ;        show word "number of reproductive" count adults with [reprod = 1 and hab = ? and sex = 0]
            while [count voles with [stat = 1 and sex = 0 and reprod = 1 and hab = ? ] < maxreproductive AND any? potential_reprod]
            [
              ask one-of potential_reprod [
                set reprod 1    
              ];; close the loop for one of the potentially reproductive that now become reproductive
              set potential_reprod voles with [stat = 1 and sex = 0 and hab = ? and mature = 1 and reprod != 1]
              ;          show word "potentially reproductive here"  count potential_reprod
            ] ;; close the loop for the threshold of reproductive females 
          ] ;; close the loop testing if any mature females
        ] ;; close the loop for going through each enclosure
    ]  ;; close the loop for mature but not reproductive females
  
  ;; asking all reproductive females to reproduce
  ask voles with [stat = 1 and sex = 0 and reprod = 1]
    [
      let myhab hab
      ;      show word "myhab" myhab
      let males voles with [stat = 1 and sex = 1]
      ;      show word "males in the area" males 
      let dom_males males with [reprod = 1]
      ;      show word "dom-males in all area" dom_males
      ;      show word "dommales on my patches " any? dom_males with [hab = myhab]
      ;; testing if there are dominant males in the territory
      ifelse any? dom_males with [hab = myhab] 
        [
          ;        show word "number of dominant males on my patches" count dom_males with [hab = myhab]
          ;        show word "Id of dommale" [who] of one-of dom_males with [hab = myhab]
          if mydom = -1
            [set mydom [who] of one-of dom_males with [hab = myhab]]
          ;        show word "mydom after update" mydom
          produce
        ] ;; close for present dominant males
      
      ;; else, testing if there any adult males in the territory
        [
          ;        show word "any? males on my patches" any? males with [hab = myhab]
          ;        show word "any? mature males on my patches" any? males with [hab = myhab and mature = 1]
          if any? males with [hab = myhab and mature = 1]
          [
            ask one-of males with [hab = myhab and mature = 1]
            [
              set reprod 1
              set mydom count voles with [stat = 1 and sex = 0 and hab = myhab and reprod = 1] 
              ;; setting a lable mydom for a dominant male
              
            ] 
            ;; setting the lable mydom for reproductive females depending on the dominant male  
            set mydom [who] of one-of males with [hab = myhab and reprod  = 1]
            ;          show word "my dominant male" mydom
            ;; setting this mydom to all the reproductive females on these patches
            ask voles with [stat = 1 and sex = 0 and reprod = 1 and hab = myhab]
            [set mydom [mydom] of myself] 
            produce
          ]
        ]  ;; close for other adult males in the patch
    ]  ;; close the loop for all reproductive females
end

to update-status
  ask voles with [stat = 1][
    set age age + 1
    if mature = 0
    [
      if week >= 17 and week < 22
      [
        set mature 1
      ]
      if week >= 22 and week < 26
      [
        ifelse random-bernoulli 0.8
        [set mature 1]
        [set mature 0]
      ]
      if week >= 26 and week < 30
      [
        ifelse random-bernoulli 0.6
        [set mature 1]
        [set mature 0]
      ]
      if week >= 30 and week < 35
      [
        ifelse random-bernoulli 0.4
        [set mature 1]
        [set mature 0]
      ]
      if week >= 35 and week < 39 
      [
        ifelse random-bernoulli 0.2
        [set mature 1]
        [set mature 0]
      ]
      if (week >= 39 and week <= 52) OR (week >= 1 and week < 17)
      [
        set mature 0
      ] 
    ]
    ;    show word "my mature" mature
    
    if sex = 0
    [set weeks_since_rep weeks_since_rep + 1
      ;      show word "weeks since rep now" weeks_since_rep
    ]
  ]
  ask voles with [stat = 0][
    set age age + 1
    if age = 5 [set stat 1
      set reprod 0  ;; this should not be needed, should be initiated for subadults at birth now
      set numlitters 0
      set mydom -1
      if week >= 17 and week < 22
      [
        set mature 1
      ]
      if week >= 22 and week < 26
      [
        ifelse random-bernoulli 0.8
        [set mature 1]
        [set mature 0]
      ]
      if week >= 26 and week < 30 
      [
        ifelse random-bernoulli 0.6
        [set mature 1]
        [set mature 0]
      ]
      if week >= 30 and week < 35 
      [
        ifelse random-bernoulli 0.4
        [set mature 1]
        [set mature 0]
      ]
      if week >= 35 and week < 39 
      [
        ifelse random-bernoulli 0.2
        [set mature 1]
        [set mature 0]
      ]
      
      if (week >= 39 and week <= 52) OR (week >= 1 and week < 17)
      [
        set mature 0
      ] 
      ifelse sex = 0
      [
        set color red
        set f_reprod 0
        set weeks_since_rep 4
      ]
      [set color blue]
    ]
  ]
  
  if week = 44 ;; because this will be just before outputting
  [ask voles with [stat = 1 and sex = 0 and numlitters != 0]
    [set numlitters 0]
  ask voles with [stat = 1 and sex = 0 and num_wean != 0]
    [set num_wean 0]
  ]
end

to produce
  ;; 1. checking if numlitters is 0, and if so and the female is reproducing the first time in this reproduction period,
  ;;  then draw the number of litters to be reproduced
  ifelse (f_reprod = 0 AND numlitters = 0)
    [
      set numlitters random-poisson Numlit
      if numlitters > 5 [set numlitters Max_numlit]
      if numlitters <= 0 [set numlitters Min_numlit]
      set f_reprod 1
      
      ;; 2. checking if time since the last reproduction is > 2 weeks
      if weeks_since_rep > 2
        [
          ;; draw number of weanlings depending on the period in the year and sociality
          let myhab hab
          ;; counting the number of social females in this enclosure
          let femsoc count voles with [stat = 1 and sex = 0 and reprod = 1 and hab = myhab]
          ;          show word "number of social reproducing females here" femsoc
          ;; estimating the overlap as a function of the number of social females
          let overlap 0
          ifelse socialfem = TRUE [
            if femsoc = 2
            [set overlap 50]
          ]
          ;; if females are not social
          [set overlap 0]
          
          let num_wean_log a_rep  + b_rep * overlap + (random-float Max_repuni) 
          set num_wean round (exp num_wean_log)
          if num_wean < 0 [set num_wean 0]
          if num_wean > 6 [set num_wean Max_wean]
          
          hatch-voles num_wean 
          [
            set age 0
            set stat 0
            set weeks_since_rep 0
            set reprod 0
            set mature 0
            set numlitters 0
            set f_reprod 0
            set mydom -1 
            set family [who] of myself
            ;            show word "my family is" family
            ifelse random-bernoulli 0.5
              [
                set color red
                set sex 0]
              [
                set color blue
                set sex 1]
          ]
          set weeks_since_rep 0
          set numlitters numlitters - 1
          ;          show word "weeks since reproduction" weeks_since_rep
          ;          show word "numlitters after giving 1 birth" numlitters
        ];; close loop for checking 2 weeks since reproduction
    ]  ;; close the loop for mature females reproducing for the first time
    
     
  ;; else if females have reproduced at least once already (f_reprod != 0)
  ;;  (note: it is not possible to have f_reprod = 0 and numlitters > 0)
    [
      if numlitters != 0
        [
          ;; 2. checking if the time since last reproduction is > 2 weeks
          if weeks_since_rep > 2
            [
              ;; draw number of weanlings depending on the period in the year and sociality
              let myhab hab
              ;; counting the number of social females in this enclosure
              let femsoc count voles with [stat = 1 and sex = 0 and reprod = 1 and hab = myhab]
              ;; estimating the overlap as a function of the number of social females
              let overlap 0
              ifelse socialfem = TRUE [
                if femsoc = 2 
                [set overlap 50]
              ]
              ;; if females are not social
              [set overlap 0]
              
              let num_wean_log a_rep + b_rep * overlap + (random-float Max_repuni)  
              set num_wean round (exp num_wean_log)
              if num_wean < 0 [set num_wean 0]
              if num_wean > 6 [set num_wean Max_wean]
              
              hatch-voles num_wean 
              [
                set age 0
                set stat 0
                set weeks_since_rep 0
                set reprod 0
                set mature 0
                set numlitters 0
                set f_reprod 0
                set mydom -1 
                set family [who] of myself
                ifelse random-bernoulli 0.5
                [
                  set color red
                  set sex 0]
                [
                  set color blue
                  set sex 1]
              ]
              
              set weeks_since_rep 0
              set numlitters numlitters - 1
              ;              show word "weeks since reproduction" weeks_since_rep
            ]  ;; close for the period > 2 weeks since the last litter
        ]  ;; close the loop for females that still have some litters to produce
    ]   ;; close the loop for the female that reproduced at least once already
end


to do-plots-stat
  
  ;;;;;;;;;;;;;;;;;;;;;;;;;     pop dynamics      ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  set totind fput count voles totind
  set totad fput count voles with [stat = 1] totad
  set totsubad fput count voles with [stat = 0] totsubad
  set weeks fput ticks weeks
 
end

to do-spring-observed
  
   ;;;;;;;;;;;;;;;;;;;;;;;; Statistics for the counts observed in spring  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  set obs_springsize count voles
  set springtotobs fput obs_springsize springtotobs
;  show word "totobs" springtotobs
  set Sdate fput ticks Sdate
  set-current-plot "SpringObserved"
  set-current-plot-pen "all"
  plot obs_springsize
    
end

to do-autumn-observed
  
   ;;;;;;;;;;;;;;;;;;;;;;;; Statistics for the counts observed in autumn  ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
  
  set obs_autumnsize count voles
  set autumntotobs fput obs_autumnsize autumntotobs
  set predators fput predat predators
;  show word "predators" predators
  set Adate fput ticks Adate
  set-current-plot "AutumnObserved"
  set-current-plot-pen "all"
  plot obs_autumnsize    
end

to calc-R
  (r:putdataframe "dat" "numind" totind "week" weeks "numad" totad "numsubad" totsubad "predators" predators)
  show word "numind" r:get "dat$numind"
  show word "mean(numind)" r:get "mean(unlist(dat$numind))"
  show word "sd(numind)" r:get "sd(unlist(dat$numind))"
  show word "length(week)"r:get "length(dat$week)"
  r:eval "hist(unlist(dat$numind), col = 1)"
  show word "numad" r:get "dat$numad"
  show word "mean(numad)" r:get "mean(unlist(dat$numad))"
  show word "sd(numad)" r:get "sd(unlist(dat$numad))"
  r:eval "dat$GR <- numeric(length(dat$week))"
  r:eval "for (i in 2:length(dat$week)){dat$GR[i] <- dat$numind [i] / dat$numind[i-1]} "
  r:eval "GR <- dat$GR[-1]"
  show word "GR" r:get "GR"
  show word "mean GR" r:get "mean(GR)"
  show word "geommean GR" r:get "exp(mean(log(GR)))"
  show word "sd GR" r:get "(sd(GR))"
  show word "geom sd GR" r:get "exp(sd(log(GR)))"
  r:eval "plot(dat$week, dat$numind, type = \"l\")"

end

to Scalcobs-R
  set springtotobs reverse springtotobs
  set Sdate reverse Sdate
  (r:putdataframe "dat1" "Snumind" springtotobs "week" Sdate)
  show word "Snumind" r:get "dat1$Snumind"
  show word "mean(Snumind)" r:get "mean(unlist(dat1$Snumind))"
  show word "sd(Snumind)" r:get "sd(unlist(dat1$Snumind))"
  show word "length(week)"r:get "length(dat1$week)"
  r:eval "hist(unlist(dat1$Snumind), col = 1)"
  r:eval "plot(dat1$week, dat1$Snumind, type = \"b\")" 
    
  ;;;;;;;growth rate
  r:eval "dat1$SGR <- numeric(length(dat1$week))"
  r:eval "for (i in 2:length(dat1$week)){dat1$SGR[i] <- dat1$Snumind [i] / dat1$Snumind[i-1]} "
  r:eval "SGR <- dat1$SGR[-1]"
  show word "SpringGR" r:get "SGR"
  show word "length (SpringGR)" r:get "length(SGR)"
  show word "mean SpringGR" r:get "mean(SGR)"
  show word "geommean SpringGR" r:get "exp(mean(log(SGR)))"
  show word "sd SpringGR" r:get "(sd(SGR))"
  show word "geom sd SpringGR" r:get "exp(sd(log(SGR)))"
  r:eval "Spoplag <- dat1$Snumind[-length(dat1$Snumind)]"
  show word "Spoplag" r:get "Spoplag"
  
end

to ScalcDD-R
 r:eval "plot(Spoplag, SGR, type = \"p\")"
end

to ScalclogDD-R
  r:eval "plot(log(Spoplag), log(SGR), type = \"b\")"
end

to ShistPop
r:eval "hist(dat1$Snumind)" 
end

to ScalclogNt
  r:eval "dat1$Slognum <- log(1 + dat1$Snumind)"
  show word "log(1 + Spop)" r:get "dat1$Slognum"
  r:eval "plot(dat1$week, dat1$Slognum, type = \"b\")"
end

to Sacf
  r:eval "tsSpring <- ts(dat1$Slognum)"
  r:eval "acf(tsSpring)"
end


to Acalcobs-R
  let predpop []
  let autumnpop []
  let autdate []
  
  ;; removing the first several years (no predator initiated yet)
  ifelse pred = TRUE
  [
  set autumnpop reverse autumntotobs
  set autumnpop remove-item (0) autumnpop
  set autumnpop remove-item (0) autumnpop
  set autumnpop remove-item (0) autumnpop
  set autumnpop remove-item (0) autumnpop
  show word "autumntotobs, predation" autumnpop
  
  set predpop reverse predators
  set predpop remove-item (0) predpop
  set predpop remove-item (0) predpop
  set predpop remove-item (0) predpop
  set predpop remove-item (0) predpop  
  show word "predpop, predation" predpop
  
  set autdate reverse Adate
  set autdate remove-item (0) autdate
  set autdate remove-item (0) autdate
  set autdate remove-item (0) autdate
  set autdate remove-item (0) autdate
  show word "Adate, predation" autdate
  ]
  [
    set autumnpop reverse autumntotobs
    set predpop reverse predators
    set autdate reverse Adate
    ]
  (r:putdataframe "dat2" "Anumind" autumnpop "week" autdate "predators" predpop)
  show word "Anumind" r:get "dat2$Anumind"
  show word "class(Anumind)" r:get "class(dat2$Anumind)"
  show word "mean(Anumind)" r:get "mean(unlist(dat2$Anumind))"
  show word "sd(Anumind)" r:get "sd(unlist(dat2$Anumind))"
  show word "length(Anumind)"r:get "length(dat2$Anumind)"
  show word "length(week)"r:get "length(dat2$week)"
  show word "predpop" r:get "dat2$predators"
  show word "length predpop" r:get "length(dat2$predators)"
  r:eval "hist(unlist(dat2$Anumind), col = 1)"
  r:eval "par(mar = c(5, 4, 4, 4) + 0.3)"
  r:eval "plot(dat2$week, dat2$Anumind, type = \"b\")" 
  r:eval "par(new = TRUE)"
  r:eval "plot(dat2$week, dat2$predators, type = \"l\", axes = FALSE, bty = \"n\", xlab = \"\", ylab = \"\", col = \"red\")"
  r:eval "axis(side=4, at = pretty(range(dat2$predators)), col.axis = \"red\")"
    
  ;;;;;;;growth rate
  r:eval "dat2$AGR <- numeric(length(dat2$week))"
  r:eval "for (i in 2:length(dat2$week)){ dat2$AGR[i] <- dat2$Anumind [i] / dat2$Anumind[i-1]} "
  r:eval "AGR <- dat2$AGR[-1]"
  show word "AGR" r:get "AGR"
  show word "length (AGR)" r:get "length(AGR)"
  show word "mean AGR" r:get "mean(AGR)"
  show word "geommean AGR" r:get "exp(mean(log(AGR)))"
  show word "sd AGR" r:get "(sd(AGR))"
  show word "geom sd SGR" r:get "exp(sd(log(AGR)))"
  r:eval "Apoplag <- dat2$Anumind[-length(dat2$Anumind)]"
  show word "Apoplag" r:get "Apoplag"
  
end

to AcalcDD-R
 r:eval "plot(Apoplag, AGR, type = \"p\")"
end

to AcalclogDD-R
  r:eval "plot(log(Apoplag), log(AGR), type = \"b\")"
end

to AhistPop
r:eval "hist(dat2$Anumind)" 
show word "mean(Apopsize)" r:get "mean(dat2$Anumind)" 
end

to AcalclogNt
  r:eval "dat2$Alognum <- log(1 + dat2$Anumind)"
  show word "log(1 + Apop)" r:get "dat2$Alognum"
  r:eval "plot(dat2$week, dat2$Alognum, type = \"b\")"
end

to Aacf
  r:eval "tsAutumn <- ts(dat2$Alognum)"
  r:eval "acf(tsAutumn)"
end

to histPred
  r:eval "hist(dat2$predators)"
end

to calculate-cycle
  
  ;; 1. first cyclicity for autumn popsizes
  if length(autumntotobs) > 5
  [ 
    ;; removing several years since predators were not there yet
    let autumnpop reverse autumntotobs
    set autumnpop remove-item (0) autumnpop
    set autumnpop remove-item (0) autumnpop
    set autumnpop remove-item (0) autumnpop
    set autumnpop remove-item (0) autumnpop
    let Autdate reverse Adate
    set Autdate remove-item (0) Autdate
    set Autdate remove-item (0) Autdate
    set Autdate remove-item (0) Autdate
    set Autdate remove-item (0) Autdate
    (r:putdataframe "datautumn" "Anumind" autumnpop "week" Autdate)
    ;; assessing the amplitude
    r:eval "minA <- min(datautumn$Anumind)"
    r:eval "maxA <- max(datautumn$Anumind)"
    r:eval "ampl <- maxA / minA"
    set ampl r:get "ampl"
    
    ;; assessing the cycle period and correlation using 2 SE
    r:eval "datautumn$Alognum <- log(1 + datautumn$Anumind)"
    r:eval "tsAutumn <- ts(datautumn$Alognum)"
    r:eval "autacf <- acf(tsAutumn, plot = FALSE)"
    r:eval "SE <- sd(autacf$acf) / sqrt(length(autacf$acf))"
    ;    show word "2 * SE" r:get "2 * SE"
    
    if r:get "length(autacf$acf)" > 5
    [ 
      if is-number? r:get "autacf$acf[which.max(autacf$acf[-1])]"
        [
          ifelse (r:get "autacf$acf[which.max(autacf$acf[-1]) + 1] > 2 * SE") 
          [
            set corr_period  r:get "autacf$acf[which.max(autacf$acf[-1]) + 1]" 
            set period r:get "which.max(autacf$acf[-1])"  ]
          [set corr_period 0
            set period 0]
        ]
      
      if is-number? r:get "autacf$acf[which.min(autacf$acf[-1])]"
        [
          ifelse (r:get "autacf$acf[which.min(autacf$acf[-1]) + 1] < - 2 * SE") [
            set corr_period_half r:get "autacf$acf[which.min(autacf$acf[-1]) + 1]" 
            set period_half r:get "which.min(autacf$acf[-1])" ]
          [
            set corr_period_half 0
            set period_half 0
          ]
        ]
    ]
  ]
  
  ;; 2. calculating the period for spring popsize
  if length(springtotobs) > 5
  [ 
    ;; removing several years since predators were not there yet
    let springpop reverse springtotobs
    set springpop remove-item (0) springpop 
    set springpop remove-item (0) springpop 
    set springpop remove-item (0) springpop 
    set springpop remove-item (0) springpop 
    let Springdate reverse Sdate
    set Springdate  remove-item (0) Springdate 
    set Springdate  remove-item (0) Springdate 
    set Springdate  remove-item (0) Springdate 
    set Springdate  remove-item (0) Springdate 
    (r:putdataframe "datspring" "Snumind" springpop "week" Springdate)
    
    ;; assessing the amplitude
    r:eval "minsA <- min(datspring$Snumind)"
    r:eval "maxsA <- max(datspring$Snumind)"
    r:eval "sampl <- maxsA / minsA"
    set sampl r:get "sampl"
    
    ;; assessing the cycle period and correlation using 2 SE
    r:eval "datspring$Slognum <- log(1 + datspring$Snumind)"
    r:eval "tsSpring <- ts(datspring$Slognum)"
    r:eval "spacf <- acf(tsSpring, plot = FALSE)"
    r:eval "SES <- sd(spacf$acf) / sqrt(length(spacf$acf))"
    ;show word "SES is" r:get "SES"
    
    if r:get "length(spacf$acf)" > 5
    [ 
      if is-number? r:get "spacf$acf[which.max(spacf$acf[-1])]"
      [
        ifelse (r:get "spacf$acf[which.max(spacf$acf[-1]) + 1] > 2 * SES") [
          set Spcorr_period r:get "spacf$acf[which.max(spacf$acf[-1]) + 1]" 
          set Spperiod r:get "which.max(spacf$acf[-1])"  ]
        [set Spcorr_period 0
          set Spperiod 0]
      ]
      if is-number? r:get "spacf$acf[which.min(spacf$acf[-1])]"
      [
        ifelse (r:get "spacf$acf[which.min(spacf$acf[-1]) + 1] < - 2 * SES") [
          set Spcorr_period_half r:get "spacf$acf[which.min(spacf$acf[-1]) + 1]" 
          set Spperiod_half r:get "which.min(spacf$acf[-1])" ]
        [set Spcorr_period_half 0
          set Spperiod_half 0]
      ]
    ]
  ]
end


to dev-off
  r:eval "dev.off()"
end  
  
to-report random-bernoulli [probability-true] 
  if (probability-true < 0.0 or probability-true > 1.0) 
    [ 
      type "Warning in random-bernoulli: probability-true equals "
      print probability-true
    ]
  ifelse random-float 1.0 < probability-true
  [report true]
  [report false]
end
@#$#@#$#@
GRAPHICS-WINDOW
201
24
566
315
7
5
23.7
1
10
1
1
1
0
1
1
1
-7
7
-5
5
0
0
1
ticks
30.0

BUTTON
8
9
72
42
NIL
Setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
75
10
138
43
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
0
160
200
310
cohortsnumber
weeks
Number individuals
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"subadults" 1.0 0 -16777216 true "" "plot count voles with [stat = 0]"
"adults" 1.0 0 -955883 true "" "plot count voles with [stat = 1]"

PLOT
568
90
768
240
totind
weeks
Individuals
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"all" 1.0 0 -16777216 true "" "plot count turtles"
"predat" 1.0 0 -3844592 true "" "plot predat"

BUTTON
140
10
196
45
NIL
dev-off
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SWITCH
103
55
193
88
pred
pred
0
1
-1000

BUTTON
960
9
1016
44
NIL
calc-R
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
1
315
201
465
patches
weeks
Number ind
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"hab1" 1.0 0 -16777216 true "" "plot count turtles with [hab = 1]"
"hab2" 1.0 0 -13345367 true "" "plot count turtles with [hab = 2]"
"hab3" 1.0 0 -2674135 true "" "plot count turtles with [hab = 3]"
"hab4" 1.0 0 -817084 true "" "plot count turtles with [hab = 4]"
"hab5" 1.0 0 -6459832 true "" "plot count turtles with [hab = 5]"
"hab6" 1.0 0 -15575016 true "" "plot count turtles with [hab = 6]"

SLIDER
212
328
305
361
maxreproductive
maxreproductive
0
5
2
1
1
NIL
HORIZONTAL

PLOT
772
92
972
242
SpringObserved
weeks
Number ind
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"all" 1.0 0 -16777216 true "" "plot obs_springsize"

BUTTON
570
8
637
44
NIL
Scalcobs-R
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
638
8
701
44
NIL
ScalcDD-R
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
702
9
776
44
NIL
ScalclogDD-R
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
776
9
832
44
NIL
ShistPop
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
403
329
496
362
dispsurv
dispsurv
0
1
0.94
0.01
1
NIL
HORIZONTAL

PLOT
771
244
971
394
AutumnObserved
weeks
Number Ind
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"all" 1.0 0 -16777216 true "" "plot obs_autumnsize"

BUTTON
570
50
639
84
NIL
Acalcobs-R
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
640
50
703
84
NIL
AcalcDD-R
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
704
51
777
85
NIL
AcalclogDD-R
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
778
52
834
86
NIL
AhistPop
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
834
9
901
43
NIL
ScalclogNt\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
901
9
957
43
NIL
Sacf
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
835
50
899
84
NIL
AcalclogNt
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
901
51
957
85
NIL
Aacf
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
308
329
401
362
sumsurv
sumsurv
0
1
0.98
0.001
1
NIL
HORIZONTAL

SWITCH
103
89
193
122
socialfem
socialfem
0
1
-1000

SWITCH
12
89
102
122
maleinfantic
maleinfantic
0
1
-1000

SWITCH
12
55
103
88
FemMort
FemMort
0
1
-1000

PLOT
570
247
770
397
predators
weeks
predators
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot predat"

BUTTON
960
52
1038
86
NIL
histPred
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
212
363
305
396
Kwin
Kwin
0
70
6.5
1
1
NIL
HORIZONTAL

SWITCH
11
124
101
157
disp
disp
0
1
-1000

SLIDER
403
362
496
395
Q
Q
20
100
42
1
1
NIL
HORIZONTAL

SLIDER
212
396
305
429
Smax
Smax
0
5
2.8
0.01
1
NIL
HORIZONTAL

SLIDER
308
363
401
396
c
c
0
500
200
1
1
NIL
HORIZONTAL

SLIDER
403
397
496
430
dlow
dlow
-8
0
-4
0.01
1
NIL
HORIZONTAL

SLIDER
308
398
401
431
Ncrit
Ncrit
0
100
15
1
1
NIL
HORIZONTAL

TEXTBOX
984
104
1228
344
Note:\nthe buttons Scalcobs-R, ScalcDD-R etc are used to calculate the acf and to produce the acf plots for the model run. To use them, first let the model run, and in the end of the run press one by one the buttons starting from the left to right, first doing this for the upper row, and then for the lower one (S (in Scalcobs-R...) stands for \"spring\"; A for \"autumn\")
12
14.0
1

@#$#@#$#@
## GENERAL REMARKS ABOUT RUNNING THE MODEL

Some of the functionalities of the model will be inactive if a user does not have r extension installed and working properly on his / her computer. Please follow precisely the instructions for installing r extension for NetLogo on your machine. On the computers where r extension for NetLogo is not installed the programme can be run by deactivating (outcommenting) all the commands related to the r extension.

The buttons on the upper right side of the interface (e.g. "Scalcobs-R", "ScalcDD-R", "ScalclogDD-R"...) can be used to plot the summary statistics after running one simulation. The upper row of the buttons plots the statistics for the sampling done in spring ("S"), and the lower row - for the sampling conducted in autumn ("A" - these are the results reported in the paper). Please press the buttons in sequential order (from left to right) since the execution of the next one is dependent on the previous one.

A user can decide which submodules (e.g. extrinsic - predation; intrinsic - dispersal, female sociality, male turnover; for more information see “From individuals to population cycles: the role of extrinsic and intrinsic factors in rodent populations" by Radchuk V., Ims R.A. and Andreassen H.P.) are activated by switching on and off the respective buttons on the upper left side of the interface. The buttons stand for: FemMort - increase in female mortality in case of male turnover; maleinfantic - increase in weanling mortality in case of male turnover; disp - vole dispersal; socialfem - increase in reproductive output due to female sociality; pred - predation by mustelid.


## ODD MODEL DESCRIPTION

This is a version of mechanistic individual-based model developed to assess the alternative hypotheses behind the factors driving vole multiannual population cycles. To explore the effect of different factors on cycle formation, use the switches on the interface to des/activate some of the processes and observe the consequences for population dynamics.

The model description follows the ODD (Overview, Design concepts, Details) protocol (Grimm et al. 2006, 2010). For complete ODD protocol and further details on the model please consult “From individuals to population cycles: the role of extrinsic and intrinsic factors in rodent populations" by Radchuk V., Ims R.A. and Andreassen H.P. and Appendix B.

## PURPOSE

The purpose of the model is to assess which factors are necessary for the formation of the cyclic pattern observed in the vole populations in nature. This goal is achieved by contrasting the alternative model versions by “switching off" some of the submodels in order to reflect the four combinations of the factors hypothesized as driving vole cycles.

## ENTITIES, STATE VARIABLES AND SCALES

The model represents a typical enclosure used in experimental vole studies: an enclosure of 0.5 ha consisting of 6 habitat patches (225 m2 each) separated by the hostile matrix (Ims and Andreassen 1999, 2000, Andreassen and Ims 2001, Huitu et al. 2003). The landscape consists of grid cells (quadratic units) characterized by the nominal variable habitat that has two levels: habitat and matrix.

One time step in the model corresponds to one week, a year consists of 52 weeks, and the time horizon of the model is 35 years.
 
The entities in the model are:
	- Spatial: grid cells (quadratic units) composing the landscape and characterized by nominal variable habitat with two levels: habitat and matrix. Grid cells compose six habitat patches (characterized by an ID), separated by hostile matrix. Such a system represents a typical enclosure used in experimental vole studies (total area of 0.5 ha with six habitat patches of 225 m2 each; Andreassen and Ims 2001).
	- Biological: individuals characterized by the following state variables: stage (weanling, subadult, adult), age (weeks), sex (female or male), family (ID of the family an individual belongs to), a Boolean maturation indicator of adults (mature), and Boolean reproductive indicating whether the mature individual is reproducing or not. Reproductive females are additionally characterized by the ID of their dominant male, variable indicating weeks since the last reproduction, and the number of litters to be produced. The sex ratio is assumed to be 1.
  

## PROCESS OVERVIEW AND SCHEDULING

Seasonality plays an important role in the vole life cycle (Korpimäki et al. 2004), with some processes occurring only during the summer. We therefore distinguish two seasons: summer (S, weeks 17-43) and winter (W, weeks 1-16 and 44-52). The model includes the following processes with the period during which they occur indicated in the brackets: reproduction (S), survival (S, W), dispersal (S), predation (week 44), and ageing (S, W). Every time step the processes occur in the following order: survival, dispersal, reproduction and ageing. Predation occurs only on the 44<sup>th</sup> week of each year and is scheduled after survival. Individuals perform all the processes but survival in a random order. For survival, first reproductive females and their weanlings (in random order) are processed, and then the survival is estimated for all other individuals in a random order.

## DESIGN CONCEPTS

_Basic Principles_:
This model is built to be able to discriminate alternative hypotheses suggested for the factors causing the vole population cycles. The question of what mechanisms underlie the formation of a regular cyclic pattern in voles intrigued scientists for decades, yet an unambiguous answer was not yet found. The main hypotheses supported in literature concern the impact of extrinsic (predation) and intrinsic (sociality, and dispersal) factors (Krebs 1996, Stenseth et al. 1996, Boonstra et al. 1998, Andreassen et al. 2013). Moreover, multi-factorial hypothesis was formulated stating that one factor is not sufficient for cycle formation; rather an interaction of several factors is needed (Krebs 1996, Stenseth et al. 1996). An individual-based model incorporating the mechanistic description of vole life-history processes offers a unique opportunity for testing a set of alternative hypotheses. This is achieved by contrasting the alternative model formulations representative of different hypotheses with a set of empirical patterns that describe vole cycles observed in the field. Thus, using IBM together with pattern-oriented modelling (POM) provide favourable settings for answering the question of what drives vole population cycles.

_Emergence_: 
Individual-based rules lead to the emergence of the spatial distribution of individuals (occupancy of different patches) and temporal population dynamics, resulting in multi-annual cycles of amplitude and period that differ as a function of processes assumed according to each tested hypothesis.

_Sensing_: 
Individual voles can sense the sex and stage of other individuals, their dominant status and family ID, and the number of other voles in the same patch.

_Interaction_: 
Interactions between individuals are indirect, modelled by: supressing the reproduction of other females when the maximum number of reproductive females per patch is reached; male infanticide via decreased weanling survival rates in case of male turnover; and decrease in female survival due to male turnover. Also in winter the interactions between individuals are mediated via intraspecific competition for resources, which is modelled using density-dependent survival.

_Stochasticity_: 
Demographic stochasticity is incorporated via Bernoulli trials to assess the survival of individuals, emigration propensity, and their maturation; and via Poisson distribution to assess the number of litters. Inter-individual variation is incorporated via uniform distribution adding a random number for each individual when estimating emigration propensity and the number of weanlings to be produced. 

_Collectives_: 
individuals belong to families, each family has ID. A family ID is assigned according to the ID of the mother. If mother dies then all weanlings in the same family die.
 
_Observation_:
Each simulation was run for 35 years (or until population went extinct) and first 5 years were discarded since predation affects the vole population from the year 5 and on. For the model analysis we recorded vole population size in the whole system and in each patch each week for each of 1000 model runs. For contrasting the model with field patterns only the population size in week 44 (1st of November) was used for calculation of 1) the mean (and SD) autumn population size across 1000 runs; 2) the cycle period using acf; 3) the amplitude defined as ratio of maximum to minimum autumn population size observed during each run; 4) the number of years during which the population is extant.


## INITIALIZATION

The model is initialized to reflect as close as possible the setup of the vole enclosure experiments (Andreassen and Ims 2001): simulations start on the week 25 with four families “released" in the system, each family consists of a mature reproductive female and the number of her weanlings drawn from Poisson distribution with mean = 4.37 (Andreassen, unpubl. data). Each family is randomly assigned to one of the patches. The age of the females is drawn randomly from the uniform distribution ([39, 52] weeks), number of litters is drawn from the Poisson distribution (mean = 3.12), and weeks since reproduction is set to 4. The age of weanlings is set to 2 weeks, their family ID is set to their mother’s ID, and sex is assigned to either a male or a female with even probability.   The predator population size (_P_) is initialized in the 5<sup>th</sup> year of the simulation by dividing the vole population size in the system (_N_) by the equilibrium prey-predator ratio (_Q_).

## INPUT DATA

The model does not use input data.

## SUBMODELS

### Reproduction

Reproduction takes place in summer. Only mature reproductive females can reproduce given there is a mature dominant male present in the same patch. There is a limit for the number of the reproductive females that can be located in the same patch, set to 2; the reproduction of other mature females is suppressed. When a female becomes reproductive, it first draws the number of litters to be produced from the Poisson distribution with mean of 3.12 (truncated at 1 and 5 individuals). Then every three weeks a female produces a litter until the maximum number of litters is reached. The number of weanlings in each litter (_Num<sub>wean</sub>_) is a function of the number of reproductive females in the same patch, reflecting positive effect of female sociality on reproductive output (Remy et al. 2013):

_Num<sub>wean</sub>_ = exp(_α<sub>rep</sub>_ + _β<sub>rep</sub>_ * _overlap_ + U[0, _b<sub>rep</sub>_]);
where _α<sub>rep</sub>_ and _β<sub>rep</sub>_ are an intercept and slope, U[0,_b<sub>rep</sub>_] is a uniform distribution with parameters 0 and _b<sub>rep</sub>_, which is used to incorporate the variation between females, and overlap is the percentage of home range overlap for reproductive females, which is set to 50% if 2 reproductive females are present in the patch and 0% if 1 female is present or not sociality in reproduction is included ( for testing the hypothesis of no sociality effect). If the estimated number of weanlings exceeds 6, it is set to 6.

### Survival

#### _WINTER_

Winter survival probability (_s<sub>win</sub>_) is negative density-dependent so as to yield the population rate of change during winter estimated by Aars and Ims (2002). Aars and Ims (2002) ascribed the negative density dependent winter population growth rate to winter recruitment, however since we do not model reproduction during the winter period (due to the lack of data and knowledge to parameterize it, Krebs 2013), we assume that this negative density dependence lies in the winter survival. Therefore, the survival in winter is modelled according to Beverton and Holt population model, using the following equation:

_s<sub>win</sub>_ = 1 / (1 + (e<sup>_R<sub>max<sub>_</sup> - 1) * _N<sub>t<sub>_ / _K<sub>win<sub>_);
where _R<sub>max<sub>_ is the maximum winter population growth rate, _N<sub>t<sub>_ is the vole population size in a given patch at time _t_, _K<sub>win<sub>_ is the carrying capacity in individuals for this patch. We then each week calculate the all-winter survival probability based on the current number of individuals in the patch and re-calculate it to the weekly survival probability as: _Weekwinsurv_ = _s<sub>win</sub>_<sup>1 / 26</sup>; because winter consists of 26 weeks.



#### _SUMMER_

First reproductive females check if its dominant male is present. If it is absent or has been replaced by another male (“male turnover", Andreassen and Gundersen 2006), the two sociality-related processes can happen: male infanticide decreasing the weanlings survival and decrease in female survival. If sociality submodel is activated, then the female survival is set to _s<sub>f</sub>_ (0.87) and her weanlings survive with probability _s<sub>w</sub>_ (0.38). If mother of weanlings die, they all die irrespective of the presence of a dominant male in the patch. In case sociality submodel is not activated or a dominant male is present, the survival probability for all individuals (females, males, subadults and weanlings) is determined by a Bernoulli trial with a probability _s<sub>sum</sub>_(0.98).

### Dispersal

Only adults and subadults can disperse. First, emigration probability is determined for each individual as a function of its sex (sex), stage (stage), density of individuals in the same patch (dens) and interaction between these parameters (Andreassen and Ims 2001). 

_y<sub>em</sub>_ = _α<sub>em</sub>_ + _β<sub>sex</sub>_ * _sex_ + _β<sub>stage</sub>_ * _stage_ + _β<sub>dens</sub>_ * _num_ + _β<sub>1</sub>_ * _sex_ * _stage_ + _β<sub>2</sub>_ * _dens_ * _stage_ + _β<sub>3</sub>_ * _dens_ * _sex_ +U[0,_b<sub>em</sub>_];	

_Prob<sub>em</sub>_ = 1 / ((1+exp(-_y<sub>em</sub>_)));	
Where _α<sub>em</sub>_, _β<sub>sex</sub>_, _β<sub>stage</sub>_, _β<sub>dens</sub>_, _β<sub>1</sub>_, _β<sub>2</sub>_, and _β<sub>3</sub>_ are the coefficients as estimated by Andreassen and Ims (2001), _y<sub>em</sub>_ is emigration probability on the logit scale, and U[0,_b<sub>em</sub>_] is a uniform distribution with parameters 0 and _b<sub>em</sub>_, which is used to incorporate the inter-individual variation. A Bernoulli trial with _Prob<sub>em</sub>_ is used to decide whether an individual will disperse. If an individual leaves its patch, it is first confronted with the dispersal mortality with the survival probability _s<sub>disp</sub>_ (0.94). If it survives, it checks 5 other patches in a random order, and in case one of the patches does not contain an adult of the same sex as dispersing individual, it settles there and becomes dominant.

### Ageing and maturation

Each week individuals update their age and, if required, their stage corresponding to their age. Only adults can become mature. Maturation probability is decreasing as a function of the week number, with all adult individuals becoming mature in the week 17, and none of them getting mature from week 39 and on. 

### Predation

Predation is modelled using the predator-prey model commonly used for voles incorporating the effect of specialist predator with Type 2 functional response (Hanski et al. 1991, Hanski and Korpimaki 1995, Turchin and Hanski 1997, for detailed discussion of different predator-prey models used for voles see Hanski et al. 2001). For the sake of simplicity and computational efficiency it is applied only once a year in week 44 starting from the 5<sub>th</sub> year of the simulation. In a first step the predator population density is updated using the predator growth rate. It is calculated in one of the ways depending on the vole population density as compared to the critical prey density below which the predator cannot reproduce (_N<sub>crit</sub>_):	

_R<sub>pred</sub>_ = exp(_S<sub>max</sub>_ * (1-(_Q_ * _P_) / _N_)) if _N_ > _N<sub>crit</sub>_;
_R<sub>pred</sub>_ = exp(_d<sub>low</sub>_) if _N_ ≤ _N<sub>crit</sub>_;

where _S<sub>max</sub>_ is predator intrinsic rate of increase, _P_ and _N_ are the predator and vole population densities respectively, and _Q_ is equilibrium prey-predator ratio. If vole population density is below _N<sub>crit</sub>_ there is no reproduction and the predator population density declines exponentially with the predator growth rate _d<sub>low</sub>_ (Hanski and Korpimaki 1995). We included the possibility for predators to prey on alternative prey by setting the fixed low limit for a predator population density, _P<sub>min</sub>_ = 0.005 ind/ha, modelling the predator refuge sensu Hanski and Korpimaki (1995).
In the second step the number of prey to be killed by predator is determined only if the vole population density is higher than _N<sub>crit</sub>_, as following:

_nkill_= exp((_c_ * _P_)/((_N_ + _D_)));
where _nkill_ is the number of vole to be preyed on, _c_ is the maximum per capita predation rate, _P_ and _N_ are the predator and vole population densities respectively, and _D_ is predation half-saturation constant. If an estimated number of voles to be preyed on (_nkill_) is lower than the vole population density (_N_), then _nkill_ number of voles are killed, otherwise the number of voles to be killed is defined as a difference between the vole population density (_N_) and critical prey density (_N<sub>crit</sub>_).		

	

## CREDITS AND REFERENCES

Viktoriia Radchuk
Leibniz Institute for Zoo and Wildlife Research	
Evolutionary Ecology Department
Alfred-Kowalke-Strasse 17
10315 Berlin
Germany
radchuk.victoria@gmail.com


To cite the model, please use: Radchuk V., Ims R.A., and Andreassen, H.P. “From individuals to population cycles: the role of extrinsic and intrinsic factors in rodent populations" Ecology
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.1.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="pred_dlow" repetitions="100" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <metric>ampl</metric>
    <metric>period</metric>
    <metric>period_half</metric>
    <metric>corr_period</metric>
    <metric>corr_period_half</metric>
    <steppedValueSet variable="dlow" first="-4.5" step="0.5" last="-1.5"/>
  </experiment>
  <experiment name="final_test" repetitions="1000" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>year</metric>
    <metric>week</metric>
    <metric>count voles</metric>
  </experiment>
  <experiment name="predation_plot" repetitions="100" runMetricsEveryStep="true">
    <setup>setup</setup>
    <go>go</go>
    <metric>year</metric>
    <metric>week</metric>
    <metric>count voles</metric>
    <metric>predat</metric>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
